# Generated by roxygen2: do not edit by hand

exportMethods(baseline_asls)
exportMethods(baseline_linear)
exportMethods(baseline_peakfilling)
exportMethods(baseline_polynomial)
exportMethods(baseline_rollingball)
exportMethods(baseline_rubberband)
exportMethods(baseline_snip)
exportMethods(integrate_rectangle)
exportMethods(integrate_trapezoid)
exportMethods(ka2_strip_penalized)
exportMethods(peaks_find)
exportMethods(peaks_fwhm)
exportMethods(replace_negative)
exportMethods(replace_threshold)
exportMethods(resample_bin)
exportMethods(resample_down)
exportMethods(resample_interpolate)
exportMethods(rescale_area)
exportMethods(rescale_max)
exportMethods(rescale_min)
exportMethods(rescale_range)
exportMethods(rescale_snv)
exportMethods(rescale_total)
exportMethods(rescale_transform)
exportMethods(signal_bind)
exportMethods(signal_correct)
exportMethods(signal_drift)
exportMethods(signal_mean)
exportMethods(signal_select)
exportMethods(signal_shift)
exportMethods(signal_slice)
exportMethods(smooth_likelihood)
exportMethods(smooth_loess)
exportMethods(smooth_rectangular)
exportMethods(smooth_savitzky)
exportMethods(smooth_triangular)
exportMethods(smooth_whittaker)
exportMethods(window_sliding)
exportMethods(window_tumbling)
importFrom(grDevices,chull)
importFrom(grDevices,xy.coords)
importFrom(methods,.valueClassTest)
importFrom(methods,callGeneric)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
importFrom(stats,approx)
importFrom(stats,lm)
importFrom(stats,mad)
importFrom(stats,poly)
importFrom(stats,predict)
importFrom(stats,smooth.spline)
importFrom(stats,spline)
importFrom(stats,weighted.mean)
importFrom(utils,head)
importFrom(utils,tail)
